@@ -58,34 +58,18 @@ class BYearEnd:
 
 
 class BusinessDay:
-
-    # usage.dask: 1
-    __module__: ClassVar[object]
-
     def __mul__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 1
         """
         ...
 
-    def __radd__(self, _0: pandas._libs.tslibs.timestamps.Timestamp, /):
-        """
-        usage.dask: 1
-        """
-        ...
-
     def __rmul__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 1
         """
         ...
 
-    def __rsub__(self, _0: pandas._libs.tslibs.timestamps.Timestamp, /):
-        """
-        usage.dask: 1
-        """
-        ...
-
 
 class BusinessHour:
     def __mul__(self, _0: numpy.ndarray, /):
@@ -234,60 +218,20 @@ class DateOffset:
         """
         ...
 
-    def is_anchored(self, /):
-        """
-        usage.dask: 3
-        """
-        ...
-
 
 class Day:
-    def __init__(self, /):
-        """
-        usage.dask: 1
-        """
-        ...
-
-    # usage.dask: 1
-    __module__: ClassVar[object]
-
-    def __eq__(self, _0: Union[None, pandas.tseries.offsets.Day], /):
-        """
-        usage.dask: 9
-        """
-        ...
-
     def __mul__(self, _0: Union[numpy.ndarray, numpy.int64], /):
         """
         usage.pandas: 3
         """
         ...
 
-    def __radd__(
-        self,
-        _0: Union[
-            pandas.core.indexes.datetimes.DatetimeIndex,
-            pandas._libs.tslibs.timestamps.Timestamp,
-        ],
-        /,
-    ):
-        """
-        usage.dask: 4
-        """
-        ...
-
     def __rmul__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 1
         """
         ...
 
-    def __rsub__(self, _0: pandas._libs.tslibs.timestamps.Timestamp, /):
-        """
-        usage.dask: 1
-        """
-        ...
-
     def __truediv__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 3
@@ -356,41 +300,18 @@ class FY5253Quarter:
 
 
 class Hour:
-
-    # usage.dask: 1
-    __module__: ClassVar[object]
-
     def __mul__(self, _0: Union[numpy.ndarray, numpy.int64], /):
         """
         usage.pandas: 2
         """
         ...
 
-    def __radd__(
-        self,
-        _0: Union[
-            pandas.core.indexes.datetimes.DatetimeIndex,
-            pandas._libs.tslibs.timestamps.Timestamp,
-        ],
-        /,
-    ):
-        """
-        usage.dask: 2
-        """
-        ...
-
     def __rmul__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 2
         """
         ...
 
-    def __rsub__(self, _0: pandas._libs.tslibs.timestamps.Timestamp, /):
-        """
-        usage.dask: 1
-        """
-        ...
-
     def __rtruediv__(self, _0: Union[numpy.ndarray, numpy.timedelta64], /):
         """
         usage.pandas: 2
@@ -477,10 +398,6 @@ class Milli:
 
 
 class Minute:
-
-    # usage.dask: 1
-    __module__: ClassVar[object]
-
     def __add__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 3
@@ -493,12 +410,6 @@ class Minute:
         """
         ...
 
-    def __radd__(self, _0: pandas.core.indexes.datetimes.DatetimeIndex, /):
-        """
-        usage.dask: 1
-        """
-        ...
-
     def __rmul__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 2
@@ -539,41 +450,18 @@ class MonthBegin:
 
 
 class MonthEnd:
-
-    # usage.dask: 1
-    __module__: ClassVar[object]
-
     def __mul__(self, _0: Union[numpy.ndarray, numpy.int64], /):
         """
         usage.pandas: 3
         """
         ...
 
-    def __radd__(
-        self,
-        _0: Union[
-            pandas.core.indexes.datetimes.DatetimeIndex,
-            pandas._libs.tslibs.timestamps.Timestamp,
-        ],
-        /,
-    ):
-        """
-        usage.dask: 2
-        """
-        ...
-
     def __rmul__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 1
         """
         ...
 
-    def __rsub__(self, _0: pandas._libs.tslibs.timestamps.Timestamp, /):
-        """
-        usage.dask: 1
-        """
-        ...
-
 
 class Nano:
     def __mul__(self, _0: Union[numpy.ndarray, numpy.int64], /):
@@ -582,19 +470,6 @@ class Nano:
         """
         ...
 
-    def __radd__(
-        self,
-        _0: Union[
-            pandas._libs.tslibs.timestamps.Timestamp,
-            pandas.core.indexes.datetimes.DatetimeIndex,
-        ],
-        /,
-    ):
-        """
-        usage.dask: 2
-        """
-        ...
-
     def __rmul__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 1
@@ -629,22 +504,12 @@ class QuarterBegin:
 
 
 class QuarterEnd:
-
-    # usage.dask: 1
-    __module__: ClassVar[object]
-
     def __mul__(self, _0: Union[numpy.ndarray, numpy.int64], /):
         """
         usage.pandas: 2
         """
         ...
 
-    def __radd__(self, _0: pandas.core.indexes.datetimes.DatetimeIndex, /):
-        """
-        usage.dask: 1
-        """
-        ...
-
     def __rmul__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 1
@@ -653,10 +518,6 @@ class QuarterEnd:
 
 
 class Second:
-
-    # usage.dask: 1
-    __module__: ClassVar[object]
-
     def __add__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 3
@@ -722,56 +583,19 @@ class SemiMonthEnd:
         ...
 
 
-class Tick:
-    def is_anchored(self, /):
-        """
-        usage.dask: 6
-        """
-        ...
-
-
 class Week:
-
-    # usage.dask: 1
-    __module__: ClassVar[object]
-
     def __mul__(self, _0: Union[numpy.ndarray, numpy.int64], /):
         """
         usage.pandas: 2
         """
         ...
 
-    def __radd__(
-        self,
-        _0: Union[
-            pandas.core.indexes.datetimes.DatetimeIndex,
-            pandas._libs.tslibs.timestamps.Timestamp,
-        ],
-        /,
-    ):
-        """
-        usage.dask: 2
-        """
-        ...
-
     def __rmul__(self, _0: numpy.ndarray, /):
         """
         usage.pandas: 1
         """
         ...
 
-    def __rsub__(self, _0: pandas._libs.tslibs.timestamps.Timestamp, /):
-        """
-        usage.dask: 1
-        """
-        ...
-
-    def is_anchored(self, /):
-        """
-        usage.dask: 2
-        """
-        ...
-
 
 class WeekOfMonth:
     def __mul__(self, _0: numpy.ndarray, /):
