@@ -18,6 +18,10 @@ __all__ = ["API", "Module", "Class", "Signature", "Metadata"]
 Type = OutputType
 
 
+# If there are more than 2 optional positional only args, convert them all to variadic positional args
+MAX_OPTIONAL_POSITIONAL_ONLY_ARGS = 2
+
+
 def orjson_dumps(v, *, default):
     # orjson.dumps returns bytes, to match standard json.dumps we need to decode
     return orjson.dumps(v, default=default, option=orjson.OPT_INDENT_2).decode()  # type: ignore
@@ -72,6 +76,11 @@ class API(BaseModel):
 
     def __ior__(self, other: API) -> API:
         update_ior(self.modules, other.modules)
+        # Remove any properties which are other just other modules
+        for module_name, module in self.modules.items():
+            for property_ in list(module.properties.keys()):
+                if f"{module_name}.{property_}" in self.modules:
+                    del module.properties[property_]
         return self
 
     def json(self, **kwargs) -> str:
@@ -140,6 +149,11 @@ class Module(BaseModel):
 
         # classes
         update_ior(self.classes, other.classes)
+        # property -> classes
+        merge_intersection(
+            self.classes, self.properties, lambda class_, property: class_
+        )
+
         # function -> class constructor
         merge_intersection(self.classes, self.functions, merge_method_class)
         merge_intersection(
@@ -360,6 +374,7 @@ class Signature(BaseModel):
     var_kw: typing.Optional[typing.Tuple[str, Type]] = None
 
     metadata: typing.Dict[str, int] = pydantic.Field(default_factory=dict)
+    return_type: OutputType = None
 
     @pydantic.validator("pos_only_required")
     @classmethod
@@ -394,6 +409,13 @@ class Signature(BaseModel):
             raise ValueError(repr(all_keys))
         return values
 
+    @property
+    def return_type_annotation(self) -> typing.Optional[cst.Annotation]:
+        return_type_annotation = None
+        if self.return_type:
+            return_type_annotation = cst.Annotation(self.return_type.annotation)
+        return return_type_annotation
+
     def function_def(
         self,
         name: str,
@@ -413,6 +435,7 @@ class Signature(BaseModel):
                 [cst.SimpleStatementLine([s]) for s in self.body(indent)]
             ),
             decorators,
+            self.return_type_annotation
         )
 
     def body(self, indent: int) -> typing.Iterable[cst.BaseSmallStatement]:
@@ -494,13 +517,17 @@ class Signature(BaseModel):
 
     @classmethod
     def from_params(
-        cls, args: typing.List[object] = [], kwargs: typing.Dict[str, object] = {}
+        cls,
+        args: typing.List[object] = [],
+        kwargs: typing.Dict[str, object] = {},
+        return_type: typing.Optional[typing.Dict[str, typing.Union[str, typing.Dict]]] = {},
     ) -> Signature:
         # If we don't know what the args/kwargs are, assume the args are positional only
         # and the kwargs and keyword only
         return cls(
             pos_only_required={f"_{i}": create_type(v) for i, v in enumerate(args)},
             kw_only_required={k: create_type(v) for k, v in kwargs.items()},
+            return_type=create_type(return_type) if return_type else None
         )
 
     @classmethod
@@ -511,6 +538,7 @@ class Signature(BaseModel):
         var_pos: typing.Optional[typing.Tuple[str, typing.List[object]]] = None,
         kw_only: typing.Dict[str, object] = {},
         var_kw: typing.Optional[typing.Tuple[str, typing.Dict[str, object]]] = None,
+        return_type: typing.Optional[typing.Dict[str, typing.Union[str, typing.Dict]]] = {},
     ) -> Signature:
         return cls(
             pos_only_required={k: create_type(v) for k, v in pos_only},
@@ -524,6 +552,7 @@ class Signature(BaseModel):
                 if var_kw
                 else None
             ),
+            return_type=create_type(return_type) if return_type else None
         )
 
     def content_equal(self, other: Signature) -> bool:
@@ -543,10 +572,32 @@ class Signature(BaseModel):
         self._copy_var_pos(other)
         self._copy_kw_only(other)
         self._copy_var_kw(other)
+        self._copy_return_type(other)
 
         update_add(self.metadata, other.metadata)
+        self._trim_positional_only_args()
         return self
 
+    def _trim_positional_only_args(self):
+        """
+        If there are excss positional only args, move them to variable positional only args
+        """
+        # if we already have var pos only args, remove all positional only args
+        if (
+            self.var_pos
+            or len(self.pos_only_optional) > MAX_OPTIONAL_POSITIONAL_ONLY_ARGS
+        ):
+            var_pos_output = unify(
+                [
+                    self.var_pos[1] if self.var_pos else BottomOutput(),
+                    *self.pos_only_optional.values(),
+                ]
+            )
+            var_pos_label = self.var_pos[0] if self.var_pos else "_args"
+            self.var_pos = (var_pos_label, var_pos_output)
+            self.pos_only_optional = {}
+            self.pos_only_optional_ordering = []
+
     def _copy_pos_only(self, other: Signature) -> None:
         pos_only_required = dict(
             map(
@@ -683,6 +734,13 @@ class Signature(BaseModel):
             else (self.var_kw or other.var_kw)
         )
 
+    def _copy_return_type(self, other: Signature) -> None:
+        self.return_type = (
+            unify((self.return_type, other.return_type,))
+            if self.return_type and other.return_type
+            else (self.return_type or other.return_type)
+        )
+
 
 API.update_forward_refs()
 Class.update_forward_refs()
