@@ -149,6 +149,15 @@ class OutputTypeBase(BaseModel, abc.ABC):
     def module(self) -> typing.Optional[str]:
         return None
 
+    # Set field set to be all fields, so none are ignored even if not set
+    @property  # type: ignore
+    def __fields_set__(self) -> typing.Set[str]:  # type: ignore
+        return set(self.__values__.keys())
+
+    @__fields_set__.setter
+    def __fields_set__(self, val: typing.Set[str]) -> None:
+        pass
+
 
 class InputTypeBase(BaseModel, abc.ABC):
     @abc.abstractmethod
@@ -302,8 +311,8 @@ class DictInput(InputTypeBase):
         if self.v:
             key, value = map(unify_inputs, zip(*self.v))
         else:
-            key = BottomOutput()
-            value = BottomOutput()
+            key = ObjectOutput()
+            value = ObjectOutput()
         return DictOutput(key=key, value=value)
 
 
@@ -373,7 +382,7 @@ class NamedOutput(BaseModel):
     def from_input(cls, input: NamedInput) -> typing.Optional[NamedOutput]:
         if isinstance(input, BuiltinNamedInput):
             return cls(name=input.__root__)
-        if "<" in input.name:
+        if not input.name.isidentifier():
             return None
         return cls(name=input.name, module=input.module)
 
@@ -382,9 +391,12 @@ class NamedOutput(BaseModel):
         first_name, *rest = (
             self.module.split(".") + [self.name] if self.module else [self.name]
         )
-        expr: typing.Union[cst.Name, cst.Attribute] = cst.Name(first_name)
-        for name in rest:
-            expr = cst.Attribute(expr, cst.Name(name))
+        try:
+            expr: typing.Union[cst.Name, cst.Attribute] = cst.Name(first_name)
+            for name in rest:
+                expr = cst.Attribute(expr, cst.Name(name))
+        except cst._nodes.base.CSTValidationError:
+            return cst.Name("Unknown")
         return expr
 
 
@@ -520,11 +532,11 @@ class TypeOutput(OutputTypeBase):
         )
 
     @classmethod
-    def unify(cls, tps: typing.Iterable[TypeOutput]) -> TypeOutput:
+    def unify(cls, tps: typing.Iterable[TypeOutput]) -> typing.Union[TypeOutput, UnionOutput]:
         names = set(tp.name for tp in tps)
         if len(names) == 1:
             return TypeOutput(name=names.pop())
-        return TypeOutput()
+        return UnionOutput(options=tuple(tps))
 
     @property
     def module(self) -> typing.Optional[str]:
